@@ -4,6 +4,7 @@
     flag <- bamFlag(param, asInteger=TRUE)
     simpleCigar <- bamSimpleCigar(param)
     tagFilter <- bamTagFilter(param)
+    mapqFilter <- bamMapqFilter(param)
     which <- bamWhich(param)
     space <- 
         if (0L != length(space(which)))
@@ -14,7 +15,8 @@
 
     .io_check_exists(path(file))
     tryCatch({
-        .Call(func, .extptr(file), space, flag, simpleCigar, tagFilter, ...)
+        .Call(func, .extptr(file), space, flag, simpleCigar, tagFilter,
+              mapqFilter, ...)
     }, error=function(err) {
         stop(conditionMessage(err), "\n  file: ", path(file),
              "\n  index: ", index(file))
