@@ -12,25 +12,68 @@ setMethod(isIncomplete, "BamFile",
     .Call(.bamfile_isincomplete, .extptr(con))
 })
 
+.check_qname_arg <- function(arg, name)
+{
+    if (is.na(arg) || arg == "")
+        return(NA_character_)
+    if (length(arg) == 0L || !is(arg, "character"))
+        stop(name, " must be a single character")
+    if (nchar(arg) > 1L)
+        stop("'nchar(", name, ")' must be < 1")
+
+    arg
+}
+
+.BamFile_guessIndex <-
+    function(files)
+{
+    index <- rep(NA_character_, length(files))
+    
+    idx <- sprintf("%s.bai", files)
+    exists <- file.exists(idx)
+    index[exists] <- idx[exists]
+
+    idx <- sub("bam$", "bai", files)
+    exists <- is.na(index) & files != idx & file.exists(idx)
+    index[exists] <- idx
+
+    idx <- sub("BAM$", "BAI", files)
+    exists <- is.na(index) & files != idx & file.exists(idx)
+    index[exists] <- idx
+
+    index
+}
+
 BamFile <-
     function(file, index=file, ..., yieldSize=NA_integer_, 
-             obeyQname=FALSE, asMates=FALSE)
+             obeyQname=FALSE, asMates=FALSE, 
+             qnamePrefixEnd=NA, qnameSuffixStart=NA)
 {
     if (missing(file) || !isSingleString(file))
         stop("'file' must be character(1) and not NA")
-    if (missing(index) && file.exists(file)) {
-        idx <- sprintf("%s.bai", file)
-        index <- if (file.exists(idx))
-            idx
-        else character(0)
-    } else if (!(isSingleString(index) || 0L == length(index))) {
+    file <- .normalizePath(file)
+    if (!asMates) {
+        if (!is.na(qnamePrefixEnd) || !is.na(qnameSuffixStart))
+            warning(paste0("when 'asMates' is FALSE 'qnamePrefixEnd' ",
+                    "and 'qnameSuffixStart' are ignored"))
+    }
+    if (missing(index)) {
+        index <- .BamFile_guessIndex(file)
+        if (is.na(index))
+            index <- character()
+    }
+    if (!(isSingleString(index) || 0L == length(index))) {
         txt <- "'index', when present, must be character(0) or character(1)
             with nchar(index) > 0 and not NA"
         stop(paste(strwrap(txt), collapse="\n  "))
     }
-    .RsamtoolsFile(.BamFile, .normalizePath(file),
-                   .normalizePath(index), yieldSize=yieldSize,
-                   obeyQname=obeyQname, asMates=asMates, ...)
+    index <- .normalizePath(index)
+    qnamePrefixEnd <- .check_qname_arg(qnamePrefixEnd, "qnamePrefixEnd")
+    qnameSuffixStart <- .check_qname_arg(qnameSuffixStart, "qnameSuffixStart")
+    .RsamtoolsFile(.BamFile, path=file, index=index, yieldSize=yieldSize,
+                   obeyQname=obeyQname, asMates=asMates, 
+                   qnamePrefixEnd=qnamePrefixEnd, 
+                   qnameSuffixStart=qnameSuffixStart, ...)
 }
 
 open.BamFile <-
@@ -58,27 +101,21 @@ close.BamFile <-
 ## scanBam, filterBam, countBam
 
 setMethod(scanBamHeader, "BamFile",
-          function(files, ...)
+          function(files, ..., what=c("targets", "text"))
 {
     if (!isOpen(files)) {
         open(files)
         on.exit(close(files))
     }
-    header <- .Call(.read_bamfile_header, .extptr(files))
-    text <- strsplit(header[["text"]], "\n")[[1]]
-    tag <- sub("^(@[A-Z]{2}).*", "\\1", text)
-    text <- strsplit(sub("^@[A-Z]{2}\t(.*)", "\\1", text), "\t")
-    names(text) <- tag
-    header[["text"]] <- text
-    header
+    .Call(.read_bamfile_header, .extptr(files), c("targets", "text") %in% what)
 })
 
 setMethod(seqinfo, "BamFile",
           function(x)
 {
-    h <- scanBamHeader(x)[["targets"]]
-    o <- order(rankSeqlevels(names(h)))
-    Seqinfo(names(h)[o], unname(h)[o])
+    h <- scanBamHeader(x, what="targets")[["targets"]]
+    h <- h[!(duplicated(h) & duplicated(names(h)))]
+    Seqinfo(names(h), unname(h))
 })
 
 setMethod(obeyQname, "BamFile",
@@ -105,12 +142,51 @@ setMethod(asMates, "BamFile",
 setReplaceMethod("asMates", "BamFile", 
     function(object, ..., value)
 {
-    if (1L != length(value))
-        stop("'value' must be length 1")
+    if (!isTRUEorFALSE(value))
+        stop("'value' must be TRUE or FALSE")
     object$asMates <- value
     object
 })
 
+.checkPrefixSuffix <- function(object, value, name)
+{
+    if (!is(value, "character"))
+        stop("'value' must be a single character")
+    if (length(value))
+        if (nchar(value) > 1L)
+            stop("nchar(value) must be <= 1")
+    if (!asMates(object))
+        warning(paste0("when 'asMates' is TRUE '", name, "' is ignored"))
+}
+
+setMethod(qnamePrefixEnd, "BamFile",
+    function(object, ...)
+{
+    object$qnamePrefixEnd
+})
+
+setReplaceMethod("qnamePrefixEnd", "BamFile", 
+    function(object, ..., value)
+{
+    .checkPrefixSuffix(object, value, "qnamePrefixEnd")
+    object$qnamePrefixEnd <- value
+    object
+})
+
+setMethod(qnameSuffixStart, "BamFile",
+    function(object, ...)
+{
+    object$qnameSuffixStart
+})
+
+setReplaceMethod("qnameSuffixStart", "BamFile", 
+    function(object, ..., value)
+{
+    .checkPrefixSuffix(object, value, "qnameSuffixStart")
+    object$qnameSuffixStart <- value
+    object
+})
+
 setMethod(scanBam, "BamFile",
           function(file, index=file, ...,
                    param=ScanBamParam(what=scanBamWhat()))
@@ -129,17 +205,22 @@ setMethod(scanBam, "BamFile",
         stop(msg)
     }
     if (0L == length(bamWhat(param)) && 0L == length(bamTag(param))) {
-        txt <- "no BAM fields selected for input (niether 'bamWhat(param)'
+        txt <- "no BAM fields selected for input (neither 'bamWhat(param)'
                 nor 'bamTag(param)' defined)"
         warning(paste(strwrap(txt), collapse="\n  "))
     }
     if (!asMates(file))
         bamWhat(param) <- setdiff(bamWhat(param), c("groupid", "mate_status")) 
     reverseComplement <- bamReverseComplement(param)
+    if (is.na(qnamePrefix <- qnamePrefixEnd(file)))
+        qnamePrefix <- ""
+    if (is.na(qnameSuffix <- qnameSuffixStart(file)))
+        qnameSuffix <- ""
     tmpl <- .scanBam_template(file, param)
     x <- .io_bam(.scan_bamfile, file, reverseComplement,
                  yieldSize(file), tmpl, obeyQname(file), 
-                 asMates(file), param=param)
+                 asMates(file), qnamePrefix, qnameSuffix, 
+                 param=param)
     .scanBam_postprocess(x, param)
 })
 
@@ -156,20 +237,6 @@ setMethod(countBam, "BamFile",
     .countBam_postprocess(x, file, param)
 })
 
-### 'x' must be a list of length >= 1 where all the elements have the same
-### type so combining them is straightforward.
-.quickUnlist <- function(x)
-{
-    x1 <- x[[1L]]
-    if (is.factor(x1)) {
-        ## Fast unlisting of a list of factors that have all
-        ## the same levels in the same order.
-        structure(unlist(x), class="factor", levels=levels(x1))
-    } else {
-        do.call(c, x)  # doesn't work on list of factors
-    }
-}
-
 ### NOTE: Not exported but used in the GenomicAlignments package!
 ### 'bamfile' must be a BamFile object. Returns a named list with 1 element
 ### per loaded column.
@@ -205,7 +272,7 @@ setMethod(countBam, "BamFile",
     ans1 <- lapply(setNames(bamWhat(param), bamWhat(param)),
                    function(nm) {
                        tmp <- lapply(res, "[[", nm)
-                       .quickUnlist(tmp)
+                       S4Vectors:::quick_unlist(tmp)
                    })
 
     ## Extract the "tag" cols.
@@ -222,7 +289,7 @@ setMethod(countBam, "BamFile",
                                          }
                                          tag_elt
                                      })
-                       .quickUnlist(tmp)
+                       S4Vectors:::quick_unlist(tmp)
                    })
     ## Put all the cols together and return them.
     c(ans1, ans2, ans3)
@@ -242,6 +309,10 @@ setMethod(countBam, "BamFile",
 
     tmpl <- .scanBam_template(file, param)
     reverseComplement <- bamReverseComplement(param)
+    if (is.na(qnamePrefix <- qnamePrefixEnd(file)))
+        qnamePrefix <- ""
+    if (is.na(qnameSuffix <- qnameSuffixStart(file)))
+        qnameSuffix <- ""
 
     dest <- .Call(.bamfile_open, destination, path(file), "wb")
     on.exit(.Call(.bamfile_close, dest))
@@ -249,7 +320,8 @@ setMethod(countBam, "BamFile",
     n_tot <- 0L
     repeat {
         buf <- .io_bam(.prefilter_bamfile, file, param=param,
-                       yieldSize, obeyQname(file), asMates(file))
+                       yieldSize, obeyQname(file), asMates(file),
+                       qnamePrefix, qnameSuffix)
         if (0L == .Call(.bambuffer_length, buf))
             break
 
@@ -341,4 +413,6 @@ setMethod(show, "BamFile", function(object) {
     callNextMethod()
     cat("obeyQname:", obeyQname(object), "\n")
     cat("asMates:", asMates(object), "\n")
+    cat("qnamePrefixEnd:", qnamePrefixEnd(object), "\n")
+    cat("qnameSuffixStart:", qnameSuffixStart(object), "\n")
 })
