@@ -1,5 +1,13 @@
 fl <- system.file("extdata", "ex1.bam", package="Rsamtools")
 
+as_data.frame <- function(x) {
+    data.frame(space=factor(names(unlist(x)),
+                 levels=seqlevels(x)),
+               start=start(unlist(x)),
+               end=end(unlist(x)),
+               width=width(unlist(x)))
+}
+
 test_countBam <- function()
 {
     checkEquals(data.frame(space=NA, start=NA, end=NA, width=NA,
@@ -10,7 +18,7 @@ test_countBam <- function()
     which <- RangesList(seq1=IRanges(1000, 2000),
                         seq2=IRanges(c(100, 1000), c(1000, 2000)))
     p1 <- ScanBamParam(which=which)
-    exp <- cbind(as.data.frame(which),
+    exp <- cbind(as_data.frame(which),
                  file=basename(fl),
                  records=c(612L, 1169L, 642L),
                  nucleotides=c(21549, 41235, 22640))
@@ -19,7 +27,7 @@ test_countBam <- function()
     which <- RangesList(seq2=IRanges(c(100, 1000), c(1000, 2000)),
                         seq1=IRanges(1000, 2000))
     p2 <- ScanBamParam(which=which)
-    exp <- merge(as.data.frame(which), exp, sort=FALSE)
+    exp <- merge(as_data.frame(which), exp, sort=FALSE)
     rownames(exp) <- NULL
     checkIdentical(exp, countBam(fl, param=p2))
 }
@@ -29,7 +37,7 @@ test_countBam_index <- function()
     which <- RangesList(seq1=IRanges(1000, 2000),
                         seq2=IRanges(c(100, 1000), c(1000, 2000)))
     p1 <- ScanBamParam(which=which)
-    exp <- cbind(as.data.frame(which),
+    exp <- cbind(as_data.frame(which),
                  file="ex1_noindex.bam",
                  records=c(612L, 1169L, 642L),
                  nucleotides=c(21549, 41235, 22640))
