@@ -42,8 +42,8 @@ class BamFileIterator : public BamIterator {
 public:
 
     // constructor / destructor
-    BamFileIterator(const bam_index_t *bindex) :
-        BamIterator(bindex), file_done(false) {}
+    BamFileIterator(bamFile bfile, const bam_index_t *bindex) :
+        BamIterator(bfile, bindex), file_done(false) {}
 
 };
 
