@@ -22,12 +22,12 @@ bam_mates_t *bam_mates_new()
 {
     bam_mates_t *mates = Calloc(1, bam_mates_t);
     mates->n = 0;
-    mates->mated = NA_INTEGER;
+    mates->mated = MATE_UNKNOWN;
     mates->bams = NULL;
     return mates;
 }
 
-void bam_mates_realloc(bam_mates_t *result, int n, int mated)
+void bam_mates_realloc(bam_mates_t *result, int n, MATE_STATUS mated)
 {
     for (int i = 0; i < result->n; ++i) {
         bam_destroy1((bam1_t *) result->bams[i]);
@@ -36,10 +36,11 @@ void bam_mates_realloc(bam_mates_t *result, int n, int mated)
 
     // Realloc(p, 0, *) fails inappropriately
     if (n == 0) {
-	Free(result->bams);
-	result->bams = NULL;
-    } else
-	result->bams = Realloc(result->bams, n, const bam1_t *);
+        Free(result->bams);
+        result->bams = NULL;
+    } else {
+        result->bams = Realloc(result->bams, n, const bam1_t *);
+    }
     result->n = n;
     result->mated = mated;
 }
@@ -47,7 +48,7 @@ void bam_mates_realloc(bam_mates_t *result, int n, int mated)
 void bam_mates_destroy(bam_mates_t *mates)
 {
     for (int i = 0; i < mates->n; ++i)
-	bam_destroy1((bam1_t *) mates->bams[i]);
+        bam_destroy1((bam1_t *) mates->bams[i]);
     Free(mates->bams);
     Free(mates);
 }
@@ -59,20 +60,23 @@ int bam_mate_read(bamFile fb, bam_mate_iter_t iter, bam_mates_t *mates)
 }
 
 // BamRangeIterator methods
-bam_mate_iter_t bam_mate_range_iter_new(const bam_index_t *bindex,
-                                        int tid, int beg, int end)
+bam_mate_iter_t bam_mate_range_iter_new(bamFile bfile,
+                                        const bam_index_t *bindex, int tid,
+                                        int beg, int end)
 {
     bam_mate_iter_t iter = Calloc(1, struct _bam_mate_iter_t);
-    iter->b_iter = new BamRangeIterator(bindex, tid, beg, end);
+    iter->b_iter = new BamRangeIterator(bfile, bindex, tid, beg, end);
     return iter;
 }
 
 int bam_fetch_mate(bamFile bf, const bam_index_t *idx, int tid, int beg, 
                    int end, void *data, bam_fetch_mate_f func)
 {
+    BAM_DATA bd = (BAM_DATA) data;
     int n_rec;
     bam_mates_t *mates = bam_mates_new();
-    bam_mate_iter_t iter = bam_mate_range_iter_new(idx, tid, beg, end);
+    bam_mate_iter_t iter = bam_mate_range_iter_new(bf, idx, tid, beg, end);
+    iter->b_iter->set_bam_data(bd);
     while ((n_rec = bam_mate_read(bf, iter, mates) > 0))
         func(mates, data);
     bam_mate_iter_destroy(iter);
@@ -81,23 +85,30 @@ int bam_fetch_mate(bamFile bf, const bam_index_t *idx, int tid, int beg,
 }
 
 // BamFileIterator methods
-bam_mate_iter_t bam_mate_file_iter_new(const bam_index_t *bindex)
+bam_mate_iter_t bam_mate_file_iter_new(bamFile bfile,
+                                       const bam_index_t *bindex)
 {
     bam_mate_iter_t iter = Calloc(1, struct _bam_mate_iter_t);
-    iter->b_iter = new BamFileIterator(bindex);
+    iter->b_iter = new BamFileIterator(bfile, bindex);
     return iter;
 }
 
-int samread_mate(bamFile fb, const bam_index_t *bindex,
-                 bam_mate_iter_t *iter_p, bam_mates_t *mates)
+int samread_mate(bamFile bfile, const bam_index_t *bindex,
+                 bam_mate_iter_t *iter_p, bam_mates_t *mates,
+                 void *data)
 {
+    BAM_DATA bd = (BAM_DATA) data;
     bam_mate_iter_t iter;
+    int status;
     if (NULL == *iter_p)
-        *iter_p = bam_mate_file_iter_new(bindex);
+        *iter_p = bam_mate_file_iter_new(bfile, bindex);
     iter = *iter_p;
+    iter->b_iter->set_bam_data(bd);
     iter->b_iter->iter_done = false;
     // single yield
-    return bam_mate_read(fb, iter, mates);
+    status = bam_mate_read(bfile, iter, mates);
+    iter->b_iter->set_bam_data(NULL);
+    return status;
 }
 
 
