@@ -12,7 +12,7 @@ typedef struct {
 #define TABIXFILE(b) ((_TABIX_FILE *) R_ExternalPtrAddr(b))
 
 typedef SEXP SCAN_FUN(tabix_t *tabix, ti_iter_t iter, const int size,
-                      SEXP state);
+                      SEXP state, SEXP rownames);
 
 SCAN_FUN tabix_as_character;
 SCAN_FUN tabix_count;
@@ -26,6 +26,7 @@ SEXP index_tabix(SEXP filename, SEXP format,
                  SEXP seq, SEXP begin, SEXP end,
                  SEXP skip, SEXP comment, SEXP zeroBased);
 SEXP header_tabix(SEXP ext);
-SEXP scan_tabix(SEXP ext, SEXP space, SEXP yield, SEXP fun, SEXP state);
+SEXP scan_tabix(SEXP ext, SEXP space, SEXP yield, SEXP fun, 
+                SEXP state, SEXP rownames);
 
 #endif
